@@ -1,10 +1,11 @@
+#FIXME why does knitr print the returned S3 class twice in the example?
 #' Get parameter subset of only certain parameters.
 #' 
 #' Parameter order is not changed.
 #' @param par.set [\code{\link{ParamSet}}]\cr
 #'   Parameter set.
 #' @param type [\code{character}]\cr
-#'   Vector of allowed types, subset of: \dQuote{numeric}, \dQuote{integer}, \dQuote{numericvector}, \dQuote{integervector}, \dQuote{discrete}, \dQuote{discretevector}, \dQuote{logical}, \dQuote{function}, \dQuote{untyped}.
+#'   Vector of allowed types, subset of: \dQuote{numeric}, \dQuote{integer}, \dQuote{numericvector}, \dQuote{integervector}, \dQuote{discrete}, \dQuote{discretevector}, \dQuote{logical}, \dQuote{logicalvector}, \dQuote{function}, \dQuote{untyped}.
 #' @return [\code{\link{ParamSet}}].
 #' @examples
 #' ps <- makeParamSet(
@@ -20,7 +21,7 @@
 #' filterParams(ps, c("integer","numeric"))
 #' @export 
 filterParams = function(par.set, type) {
-  checkArg(type, subset=c("numeric", "integer", "numericvector", "integervector", "discrete", "discretevector", "logical", "function", "untyped"))
+  checkArg(type, subset=c("numeric", "integer", "numericvector", "integervector", "discrete", "discretevector", "logical", "logicalvector", "function", "untyped"))
   par.set$pars = Filter(function(p) p$type %in% type, par.set$pars) 
   return(par.set)
 }
\ No newline at end of file
