@@ -4,6 +4,7 @@
 #'
 #' @param n [\code{integer(1)}]\cr 
 #'   Number of samples in design.   
+#'   Default is 10.
 #' @param par.set [\code{\link{ParamSet}}]\cr
 #'   Parameter set.
 #' @param fun [\code{function}]\cr
@@ -18,17 +19,23 @@
 #' @param ints.as.num [\code{logical(1)}]\cr
 #'   Should parameters of type \dQuote{integer} or \dQuote{integervector} generate numeric columns?
 #'   Default is \code{FALSE}.  
-#' @param discrete.as.factors [\code{logical(1)}]\cr
+#' @param discretes.as.factor [\code{logical(1)}]\cr
 #'   Should discrete parameters have columns of type \dQuote{factor} in result?
 #'   Otherwise character columns are generated.
 #'   Default is \code{TRUE}.  
+#' @param logicals.as.factor [\code{logical(1)}]\cr
+#'   Should logical parameters have columns of type \dQuote{factor} in result?
+#'   Otherwise logical columns are generated.
+#'   Default is \code{FALSE}.  
 #' @return The created design is a data.frame. Columns are named by the ids of the parameters.
 #'   If the \code{par.set} argument contains a vector parameter, its corresponding column names  
 #'   in the design are the parameter id concatenated with 1 to dimension of the vector.   
 #'   The data type of a column 
 #'   is defined in the following way. Numeric parameters generate numeric columns, integer parameters generate numeric/integer columns, 
-#'   logical parameters generate logical columns.
+#'   logical parameters generate logical/factor columns.
 #'   For discrete parameters the value names are used and character or factor columns are generated.
+#'   Dependent parameters whose constaints are unsatisfied generate \code{NA} entries in their
+#'   respective columns.
 #'   The result will have an \code{logical(1)} attribute \dQuote{trafo}, 
 #'   which is set to the value of argument \code{trafo}.
 #' @export 
@@ -43,13 +50,11 @@
 #' # with trafo 
 #' ps <- makeParamSet(
 #'   makeNumericParam("x", lower=-2, upper=1), 
-#'   makeNumericVectorParam("y", length=2, lower=0, upper=1, trafo=function(x) x/sum(x)) 
+#'   makeNumericVectorParam("y", len=2, lower=0, upper=1, trafo=function(x) x/sum(x)) 
 #' )
 #' generateDesign(10, ps, trafo=TRUE)
-generateDesign = function(n, par.set, fun, fun.args=list(), trafo=FALSE, ints.as.num=FALSE, discrete.as.factors=TRUE) {
-  if (!missing(n)) {
-    n = convertInteger(n)
-  }
+generateDesign = function(n=10L, par.set, fun, fun.args=list(), trafo=FALSE, ints.as.num=FALSE, discretes.as.factor=TRUE, logicals.as.factor=FALSE) {
+  n = convertInteger(n)
   checkArg(n, "integer", len=1L, na.ok=FALSE)
   checkArg(par.set, "ParamSet")
   requirePackages("lhs", "generateDesign")
@@ -60,7 +65,7 @@ generateDesign = function(n, par.set, fun, fun.args=list(), trafo=FALSE, ints.as
   checkArg(fun.args, "list")
   checkArg(trafo, "logical", len=1L, na.ok=FALSE)
   checkArg(ints.as.num, "logical", len=1L, na.ok=FALSE)
-  checkArg(discrete.as.factors, "logical", len=1L, na.ok=FALSE)
+  checkArg(discretes.as.factor, "logical", len=1L, na.ok=FALSE)
   
   if (length(par.set$pars) == 0)
     stop("par.set must not be empty!")        
@@ -77,47 +82,67 @@ generateDesign = function(n, par.set, fun, fun.args=list(), trafo=FALSE, ints.as
   k = sum(getParamLengths(par.set))
   des = do.call(fun, c(list(n=n, k=k), fun.args))
   des = as.data.frame(des)
-
+  
   col = 0
   for (i in 1:length(pars)) {
     p = pars[[i]]
     cc = rev(col)[1]
-    if (p$type %in% c("numericvector", "integervector", "discretevector")) 
-      col = (cc + 1) : (cc + p$length)   
+    if (p$type %in% c("numericvector", "integervector", "discretevector", "logicalvector")) 
+      col = (cc + 1) : (cc + p$len)   
     else 
       col = cc + 1    
-    trafo.fun = if (trafo) p$trafo else identity
+    trafo.fun = if (trafo && !is.null(p$trafo)) p$trafo else identity
     if (p$type == "numeric")
-      des[,col] = trafo.fun((p$upper-p$lower)*des[,col] + p$lower)
+      v = (p$upper-p$lower)*des[,col] + p$lower
     else if (p$type == "integer") {
-      x = trafo.fun(as.integer(floor((p$upper-p$lower+1)*des[,col] + p$lower)))
-      des[,col] = if (ints.as.num) as.numeric(x) else x  
+      v = as.integer(floor((p$upper-p$lower+1)*des[,col] + p$lower))
     } else if (p$type == "numericvector") {
-      des[,col] = t((p$upper-p$lower)*t(des[,col]) + p$lower)
-      des[,col] = t(apply(des[,col], 1, trafo.fun))
+      v = t((p$upper-p$lower)*t(des[,col]) + p$lower)
     } else if (p$type == "integervector") {
-      x = floor((p$upper-p$lower+1)*as.matrix(des[,col]) + p$lower)
+      v = floor((p$upper-p$lower+1)*as.matrix(des[,col]) + p$lower)
       if (!ints.as.num)
-        mode(x) = "integer"
-      des[,col] = x
-      des[,col] = t(apply(des[,col], 1, trafo.fun))
-    } else if (p$type == "logical")
-      des[,col] = ifelse(des[,col] <= 0.5, FALSE, TRUE)
+        mode(v) = "integer"
+    } else if (p$type %in% c("logical", "logicalvector"))
+      v = ifelse(des[,col] <= 0.5, FALSE, TRUE)
     else if (p$type %in% c("discrete", "discretevector")) {
       ns = names(p$values)
       indices = ceiling(des[,col,drop=FALSE] * length(ns))
-      vals = lapply(1:ncol(indices), function(i) {
-        x = indices[,i]
-        x = factor(ns[x], levels=ns)
-        if (!discrete.as.factors)
-          x = as.character(x)
-        x        
+      v = lapply(1:ncol(indices), function(i) {
+        ns[indices[,i]]
       })
-      vals = do.call(function(...) data.frame(..., stringsAsFactors=FALSE), vals)
-      des[,col] = vals
+      v = do.call(function(...) data.frame(..., stringsAsFactors=FALSE), v)
+    }
+    
+    # trafo
+    if (trafo) {
+      if (p$type %in% c("numeric", "integer"))
+        v = trafo.fun(v)
+      else if (p$type %in% c("numericvector", "integervector"))
+        v = t(apply(v, 1, trafo.fun))
+    }
+    des[, col] = v
+  }
+  
+  #FIXME: *very* inefficient
+  vals = dfRowsToList(des, par.set)
+  for (i in 1:length(vals)) {
+    v = vals[[i]]
+    col = 0
+    for (j in seq_along(par.set$pars)) {
+      p = par.set$pars[[j]]
+      cc = rev(col)[1]
+      if (p$type %in% c("numericvector", "integervector", "discretevector", "logicalvector")) 
+        col = (cc + 1) : (cc + p$len)   
+      else 
+        col = cc + 1      
+      if (!is.null(p$requires) && !requiresOk(par.set, v, j)) {
+        des[i, col] = NA
+      }
     }
   }
+  
   colnames(des) = getParamIds(par.set, repeated=TRUE, with.nr=TRUE)
+  des = convertDfCols(des, ints.as.num=ints.as.num, chars.as.factor=discretes.as.factor, logicals.as.factor=logicals.as.factor)
   attr(des, "trafo") = trafo
   return(des)
 }
