@@ -9,7 +9,7 @@
 #'   makeNumericParam("u"),
 #'   makeIntegerParam("v", lower=1, upper=2),
 #'   makeDiscreteParam("w", values=1:2),
-#'   makeDiscreteVectorParam("x", length=2, values=c("a", "b"))
+#'   makeDiscreteVectorParam("x", len=2, values=c("a", "b"))
 #' )
 #' getParamLengths(ps)
 #' # the length of the vector x is 2, for all other single value parameters the length is 1. 
@@ -20,5 +20,5 @@ getParamLengths = function(par.set) {
   if (length(par.set$pars) == 0)  
     integer(0)
   else  
-    extractSubList(par.set$pars, "length")
+    extractSubList(par.set$pars, "len")
 }
